package
Version:
v0.0.0-...-b2d2174
Opens a new window with list of versions in this module.
Published: Dec 14, 2019
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func New(address string) *server
Creates new tcp server instance
type Client struct {
Server *server
}
Client holds info about connection
Send text message to client
Source Files
¶
Click to show internal directories.
Click to hide internal directories.